kdevops.lists.linux.dev archive mirror
 help / color / mirror / Atom feed
From: Scott Mayhew <smayhew@redhat.com>
To: kdevops@lists.linux.dev
Subject: [PATCH 1/6] oscheck.sh: add some special cases for cifs
Date: Fri, 12 Apr 2024 16:49:55 -0400	[thread overview]
Message-ID: <20240412205000.2329837-2-smayhew@redhat.com> (raw)
In-Reply-To: <20240412205000.2329837-1-smayhew@redhat.com>

There's a few routines where we exit without doing anything if the
filesystem is NFS.  We need to do that for CIFS as well.

Signed-off-by: Scott Mayhew <smayhew@redhat.com>
---
 workflows/fstests/scripts/oscheck.sh | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/workflows/fstests/scripts/oscheck.sh b/workflows/fstests/scripts/oscheck.sh
index 5a3167a..3421244 100755
--- a/workflows/fstests/scripts/oscheck.sh
+++ b/workflows/fstests/scripts/oscheck.sh
@@ -439,8 +439,8 @@ _check_dev_setup()
 {
 	mkdir -p $TEST_DIR
 
-	# Nothing to be done for NFS
-	if [ "$FSTYP" = "nfs" ]; then
+	# Nothing to be done for NFS or CIFS
+	if [ "$FSTYP" = "nfs" -o "$FSTYP" = "cifs" ]; then
 		return
 	fi
 
@@ -520,7 +520,7 @@ check_test_dev_setup()
 	fi
 
 	# FIXME: check server for reachability?
-	if [ "$FSTYP" = "nfs" ]; then
+	if [ "$FSTYP" = "nfs" -o "$FSTYP" = "cifs" ]; then
 		return
 	fi
 
@@ -548,7 +548,7 @@ check_dev_pool()
 {
 	DEV_POOL_RET=0
 
-	if [ "$FSTYP" = "nfs" ]; then
+	if [ "$FSTYP" = "nfs" -o "$FSTYP" = "cifs" ]; then
 		return 0
 	fi
 
-- 
2.44.0


  reply	other threads:[~2024-04-12 20:50 UTC|newest]

Thread overview: 13+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2024-04-12 20:49 [PATCH 0/6] Add an option for running fstests on CIFS Scott Mayhew
2024-04-12 20:49 ` Scott Mayhew [this message]
2024-04-12 20:49 ` [PATCH 2/6] gendisks.sh: add special case for cifs Scott Mayhew
2024-04-12 20:49 ` [PATCH 3/6] bringup: add a playbook to bring up an SMB server Scott Mayhew
2024-04-12 20:49 ` [PATCH 4/6] playbooks: add a playbook to create smb shares Scott Mayhew
2024-04-12 20:49 ` [PATCH 5/6] fstests: add an option for testing on CIFS Scott Mayhew
2024-04-12 21:42   ` Luis Chamberlain
2024-04-16 21:56     ` Scott Mayhew
2024-04-17 13:50       ` Chuck Lever III
2024-04-12 20:50 ` [PATCH 6/6] fstests: add expunges for cifs Scott Mayhew
2024-04-12 20:52 ` [PATCH 0/6] Add an option for running fstests on CIFS Chuck Lever III
2024-04-16 21:54   ` Scott Mayhew
2024-04-12 21:46 ` Luis Chamberlain

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20240412205000.2329837-2-smayhew@redhat.com \
    --to=smayhew@redhat.com \
    --cc=kdevops@lists.linux.dev \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).